@@ -130,6 +130,7 @@ class GeoTimeClassify:
         self.cont_lookup = pd.read_csv(pkg_resources.resource_stream(__name__, 'datasets/continent_code.csv'),
                                         encoding='latin-1')
         self.cont_lookup = np.asarray(self.cont_lookup["continent_name"])
+        self.FakeData= pd.read_csv(pkg_resources.resource_stream(__name__,'datasets/Fake_data.csv'), encoding='latin-1')
 
         self.day_of_week = [
             "Monday",
@@ -1469,3 +1470,5 @@ class GeoTimeClassify:
 
         return output_col
 
+    def get_Fake_Data(self):
+        return self.FakeData
